@@ -1,7 +1,7 @@
 #ifndef __GDICT_APPLET_H_
 #define __GDICT_APPLET_H_
 
-/* $Id: gdict-applet.h,v 1.12 2004/11/05 18:02:50 vnoel Exp $ */
+/* $Id: gdict-applet.h,v 1.14 2004/12/06 15:15:25 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
@@ -14,20 +14,25 @@
  */
  
 #include <panel-applet.h>
+#include "gdict-pref.h"
+#include "gdict-app.h"
 
 /* This structure contains the internal state of the gdict applet.
  * Everything the functions and signal handlers need to be able to
  * manipulate the applet should be contained within. */
 typedef struct _GDictApplet {
+        PanelApplet *parent_applet;
 	GtkWidget *applet_widget;
 	GtkWidget *image_widget;
 	GtkWidget *box;
 	GtkWidget *entry_widget;
 	GtkWidget *about_dialog;
+	GtkWidget *pref_dialog;
 	GtkTooltips *tooltips;
 	PanelAppletOrient orient;
 	gboolean handle;
 	gint panel_size;
+	GDictWindow *gdict;
 } GDictApplet;
 
 
