@@ -1,7 +1,7 @@
 #ifndef __GDICT_DEFBOX_H_
 #define __GDICT_DEFBOX_H_
 
-/* $Id: gdict-defbox.h,v 1.5 2001/11/20 15:09:47 kevinv Exp $ */
+/* $Id: gdict-defbox.h,v 1.13 2005/05/25 14:53:58 vnoel Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -15,28 +15,30 @@
  *
  */
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
-
 #include <gtk/gtk.h>
-
 #include "dict.h"
 
-#define GDICT_DEFBOX(obj)         GTK_CHECK_CAST (obj, gdict_defbox_get_type (), GDictDefbox)
-#define GDICT_DEFBOX_CLASS(klass) GTK_CHECK_CLASS_CAST (klass, gdict_defbox_get_type (), GDictDefboxClass)
-#define IS_GDICT_DEFBOX(obj)      GTK_CHECK_TYPE (obj, gdict_defbox_get_type ())
+#define GDICT_TYPE_DEFBOX            (gdict_defbox_get_type ())
+#define GDICT_DEFBOX(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GDICT_TYPE_DEFBOX, GDictDefbox))
+#define GDICT_DEFBOX_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GDICT_TYPE_DEFBOX, GDictDefboxClass))
+#define GDICT_IS_DEFBOX(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDICT_TYPE_DEFBOX))
+#define GDICT_IS_DEFBOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDICT_TYPE_DEFBOX))
+#define GDICT_DEFBOX_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GDICT_TYPE_DEFBOX, GDictDefboxClass))
 
 typedef struct _GDictDefbox        GDictDefbox;
 typedef struct _GDictDefboxClass   GDictDefboxClass;
 
+#include "gdict-app.h"
+
 struct _GDictDefbox 
 {
-    GtkTextView         text;
-    
+    GtkTextView    text;
     dict_context_t *context;
     dict_command_t *def_cmd;
     gchar          *database;
+    gpointer       gdict;
+	  gchar *fontname;
+  	int fontsize;
 };
 
 struct _GDictDefboxClass 
@@ -51,26 +53,19 @@ struct _GDictDefboxClass
 };
 
 GType	   gdict_defbox_get_type   (void);
-
-GtkWidget *gdict_defbox_new        (void);
-void 	   defbox_setup_tags 	   (GDictDefbox *defbox);
-void       gdict_defbox_destroy    (GDictDefbox *defbox);
+GtkWidget *gdict_defbox_new        (gpointer gdict);
 
 gint       gdict_defbox_lookup     (GDictDefbox *defbox, gchar *text);
 void       gdict_defbox_clear      (GDictDefbox *defbox);
-void       gdict_defbox_find       (GDictDefbox *defbox, gchar *text,
+gboolean   gdict_defbox_find       (GDictDefbox *defbox, const gchar *text,
                                     gboolean start);
 void       gdict_defbox_reset      (GDictDefbox *defbox,
-                                    dict_context_t *context);
-
-#ifdef HAVE_GNOME_PRINT
-void       gdict_defbox_print      (GDictDefbox *defbox);
-#endif
-
+				    dict_context_t *context);
+void gdict_defbox_prepare_print    (GDictDefbox *defbox);
+void gdict_defbox_print_preview (GDictDefbox *defbox);
 gchar     *gdict_defbox_get_word   (GDictDefbox *defbox);
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
-
+void gdict_defbox_zoom_in (GDictDefbox *defbox);
+void gdict_defbox_set_fontsize (GDictDefbox *defbox, int fontsize);
+void gdict_defbox_set_font (GDictDefbox *defbox, gchar *fontname);
+	
 #endif /* __GDICT_DEFBOX_H_ */
