@@ -1,4 +1,4 @@
-/* $Id: gdict-pref.c,v 1.27.2.1 2005/04/06 13:29:18 vnoel Exp $ */
+/* $Id: gdict-pref.c,v 1.30 2005/05/25 15:01:40 vnoel Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -183,15 +183,6 @@ strat_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer dat
   gdict->pref->dfl_strat = g_strdup (gconf_value_get_string (value));
 }
 
-static void
-smart_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
-{
-  GDictWindow *gdict = data;
-  GConfValue *value = gconf_entry_get_value (entry);
-    
-  gdict->pref->smart = gconf_value_get_bool (value);
-}
-
 void
 gdict_window_restore_position (GDictWindow *gdict)
 {
@@ -214,6 +205,13 @@ gdict_window_store_position (GDictWindow *gdict)
 	gdict_set_gconf_int (gdict, "window_y", y);
 }
 
+void
+gdict_window_store_font (GDictWindow *gdict)
+{
+	gdict_set_gconf_string (gdict, "fontname", gdict->defbox->fontname);
+	gdict_set_gconf_int (gdict, "fontsize", gdict->defbox->fontsize);
+}
+
 /* gdict_pref_load
  *
  * Loads configuration from config file
@@ -233,15 +231,16 @@ gdict_pref_load (GDictWindow *gdict, GDictPref *pref)
   ** Leaving it out for now */
   pref->server = gdict_get_gconf_string (gdict, "server");
   pref->port = gdict_get_gconf_int (gdict, "port");
-  pref->smart = gdict_get_gconf_bool (gdict, "smart");
-
-  gdict_add_gconf_notify (gdict, "smart", smart_changed_cb, gdict);
 
   pref->database = gdict_get_gconf_string (gdict, "database");
   gdict_add_gconf_notify (gdict, "database", database_changed_cb, gdict);
     
   pref->dfl_strat = gdict_get_gconf_string (gdict, "strategy");
   gdict_add_gconf_notify (gdict, "strategy", strat_changed_cb, gdict);
+
+	/* FIXME : we need to listen to these keys and react to changes */
+	pref->fontname = gdict_get_gconf_string (gdict, "fontname");
+	pref->fontsize = gdict_get_gconf_int (gdict, "fontsize");
     
   /* If things go bad and gconf doesn't return values, we shouldn't die so just return the 
      default schemas */
@@ -262,7 +261,6 @@ gdict_pref_new (gpointer gdict)
 
   pref = g_new0 (GDictPref, 1);
   gdict_pref_load (gdict, pref);
-  pref->smart = TRUE;
 
   return pref;
 }
