@@ -112,6 +112,7 @@ typedef struct
 	GnomeVFSFileOffset mon_offset;
 	GnomeVFSMonitorHandle *mon_handle;
 	GnomeVFSHandle *mon_file_handle;
+	gboolean monitored;
 }
 Log;
 
@@ -157,15 +158,25 @@ struct _LogviewWindow {
 
 	GtkWidget *find_bar;
 	GtkWidget *find_entry;
-	GtkToolItem *find_next;
-	GtkToolItem *find_prev;
+	GtkWidget *find_next;
+	GtkWidget *find_prev;
 	gchar *find_string;
 
+	GtkWidget *loglist;
+	GtkWidget *treeview;
+	GtkWidget *sidebar; 
+	gboolean sidebar_visible;
+  
+  GList *logs;
+
 	Log *curlog;
 
 	gboolean monitored;
 	gint timer_tag;
 	GtkClipboard *clipboard;
+	
+	PangoFontDescription *fontdesc;
+	int original_fontsize, fontsize;
 };
 
 struct _LogviewWindowClass {
@@ -173,5 +184,7 @@ struct _LogviewWindowClass {
 };
 
 void logview_set_window_title (LogviewWindow *window);
+GtkTreePath *loglist_find_logname (LogviewWindow *logview, gchar *logname);
+
 
 #endif /* __LOGVIEW_H__ */
